kernelbinder

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: CC0-1.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Driver

type Driver struct {
	// contains filtered or unexported fields
}

Driver implements binder.Transport using /dev/binder.

func Open

func Open(
	ctx context.Context,
	opts ...binder.Option,
) (_driver *Driver, _err error)

Open opens /dev/binder and initializes the driver.

func (*Driver) AcquireHandle

func (d *Driver) AcquireHandle(
	ctx context.Context,
	handle uint32,
) (_err error)

AcquireHandle increments the strong reference count for a binder handle.

func (*Driver) ClearDeathNotification

func (d *Driver) ClearDeathNotification(
	ctx context.Context,
	handle uint32,
	recipient binder.DeathRecipient,
) (_err error)

ClearDeathNotification clears a death notification for a binder handle.

func (*Driver) Close

func (d *Driver) Close(
	ctx context.Context,
) (_err error)

Close releases all acquired binder handles, the mmap, and the file descriptor.

func (*Driver) ReleaseHandle

func (d *Driver) ReleaseHandle(
	ctx context.Context,
	handle uint32,
) (_err error)

ReleaseHandle decrements the strong reference count for a binder handle.

func (*Driver) RequestDeathNotification

func (d *Driver) RequestDeathNotification(
	ctx context.Context,
	handle uint32,
	recipient binder.DeathRecipient,
) (_err error)

RequestDeathNotification registers a death notification for a binder handle.

func (*Driver) Transact

func (d *Driver) Transact(
	ctx context.Context,
	handle uint32,
	code binder.TransactionCode,
	flags binder.TransactionFlags,
	data *parcel.Parcel,
) (_reply *parcel.Parcel, _err error)

Transact performs a synchronous binder transaction.

Jump to