Documentation
¶
Index ¶
- type Driver
- func (d *Driver) AcquireHandle(ctx context.Context, handle uint32) (_err error)
- func (d *Driver) ClearDeathNotification(ctx context.Context, handle uint32, recipient binder.DeathRecipient) (_err error)
- func (d *Driver) Close(ctx context.Context) (_err error)
- func (d *Driver) ReleaseHandle(ctx context.Context, handle uint32) (_err error)
- func (d *Driver) RequestDeathNotification(ctx context.Context, handle uint32, recipient binder.DeathRecipient) (_err error)
- func (d *Driver) Transact(ctx context.Context, handle uint32, code binder.TransactionCode, ...) (_reply *parcel.Parcel, _err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Driver ¶
type Driver struct {
// contains filtered or unexported fields
}
Driver implements binder.Transport using /dev/binder.
func (*Driver) AcquireHandle ¶
AcquireHandle increments the strong reference count for a binder handle.
func (*Driver) ClearDeathNotification ¶
func (d *Driver) ClearDeathNotification( ctx context.Context, handle uint32, recipient binder.DeathRecipient, ) (_err error)
ClearDeathNotification clears a death notification for a binder handle.
func (*Driver) Close ¶
Close releases all acquired binder handles, the mmap, and the file descriptor.
func (*Driver) ReleaseHandle ¶
ReleaseHandle decrements the strong reference count for a binder handle.
func (*Driver) RequestDeathNotification ¶
func (d *Driver) RequestDeathNotification( ctx context.Context, handle uint32, recipient binder.DeathRecipient, ) (_err error)
RequestDeathNotification registers a death notification for a binder handle.
Click to show internal directories.
Click to hide internal directories.